import axios from "axios";
import { getToken } from "./token";

const request = axios.create({
  baseURL: import.meta.env.VITE_API_BASE
})

// 添加请求拦截器
request.interceptors.request.use(function (config = {}) {
  const { header = {} } = config
  const token = getToken()
  const Authorization = token ? { Authorization: token } : {};

  // 加载动画
  window.__setloading(true);

  // 在发送请求之前做些什么
  return {
    ...config,
    header: {
      ...header,
      ...Authorization,
    }
  };
}, function (error) {
  // 对请求错误做些什么
  return Promise.reject(error);
});

// 添加响应拦截器
request.interceptors.response.use(function (response) {
  window.__setloading(false);

  // 2xx 范围内的状态码都会触发该函数。
  // 对响应数据做点什么
  const { data : respData } = response;
  const { code, message, data } = respData;

  if (code === 1000) {
    return data;
  } else {
    return Promise.reject(new Error(message));
  }
}, function (error) {
  window.__setloading(false);

  // 超出 2xx 范围的状态码都会触发该函数。
  // 对响应错误做点什么
  return Promise.reject(error);
});

export default request;